@@ -3,8 +3,8 @@ package Module::Depends;
 use Parse::CPAN::Meta;
 use Cwd qw( getcwd );
 use base qw( Class::Accessor::Chained );
-__PACKAGE__->mk_accessors(qw( dist_dir debug libs requires build_requires error ));
-our $VERSION = '0.15';
+__PACKAGE__->mk_accessors(qw( dist_dir debug libs requires configure_requires build_requires error ));
+our $VERSION = '0.16';
 
 =head1 NAME
 
@@ -42,6 +42,7 @@ sub new {
         libs           => [],
         requires       => {},
         build_requires => {},
+        configure_requires => {},
         error          => '',
     });
 }
@@ -99,6 +100,11 @@ an array reference of lib lines
 A reference to a hash enumerating the prerequisite modules for this
 distribution.
 
+=head2 configure_requires
+
+A reference to a hash enumerating the prerequisite modules to configure this
+distribution.
+
 =head2 build_requires
 
 A reference to a hash enumerating the modules needed to build the
